@@ -32,6 +32,7 @@ mod use_session_storage;
 mod use_set;
 mod use_size;
 mod use_state_ptr_eq;
+mod use_swipe;
 mod use_timeout;
 mod use_title;
 mod use_toggle;
@@ -75,6 +76,7 @@ pub use use_session_storage::*;
 pub use use_set::*;
 pub use use_size::*;
 pub use use_state_ptr_eq::*;
+pub use use_swipe::*;
 pub use use_timeout::*;
 pub use use_title::*;
 pub use use_toggle::*;
